@@ -15,8 +15,8 @@ def test_legacy_multiline_to_env_conversion():
     assert env.lhcb1._element_dict is env._element_dict
     assert env.lhcb2._element_dict is env._element_dict
 
-    assert 'drift_1' in env.lhcb1.element_names
-    assert 'drift_1' not in env.lhcb2.element_names
+    assert 'drift_1/lhcb1' in env.lhcb1.element_names
+    assert 'drift_1/lhcb2' in env.lhcb2.element_names
 
     assert 'ip1' in env.lhcb1.element_names
     assert 'ip1' in env.lhcb2.element_names
