@@ -413,9 +413,6 @@ def test_multispecies_quadrupole():
     line_ref1.configure_bend_model(core=model)
     line_ref2.configure_bend_model(core=model)
 
-    # line_ref1.config.XTRACK_USE_EXACT_DRIFTS = True
-    # line_ref2.config.XTRACK_USE_EXACT_DRIFTS = True
-
     line_ref1.build_tracker()
     line_ref2.build_tracker()
 
@@ -521,9 +518,6 @@ def test_multispecies_sextupole():
     line_ref1.configure_bend_model(core=model)
     line_ref2.configure_bend_model(core=model)
 
-    # line_ref1.config.XTRACK_USE_EXACT_DRIFTS = True
-    # line_ref2.config.XTRACK_USE_EXACT_DRIFTS = True
-
     line_ref1.build_tracker()
     line_ref2.build_tracker()
 
@@ -623,8 +617,8 @@ def test_multispecies_octupole():
     line_ref1.append_element(element=xt.Marker(), name='endmarker')
     line_ref2.append_element(element=xt.Marker(), name='endmarker')
 
-    line_ref1.config.XTRACK_USE_EXACT_DRIFTS = True
-    line_ref2.config.XTRACK_USE_EXACT_DRIFTS = True
+    line_ref1.configure_drift_model(model='exact')
+    line_ref2.configure_drift_model(model='exact')
 
     line_ref1.build_tracker()
     line_ref2.build_tracker()
