@@ -158,8 +158,8 @@ def example_sequence(temp_context_default_mod):
     in: instrument, l=2;
     mo: monitor, l=1;
     pl: placeholder, l=1;
-    sb: sbend, l=2, angle=2, tilt=-2, k0=3, k1=1, k2=2, k1s=3, e1=2, e2=1, fint=3, fintx=2, hgap=1, h1=3, h2=2;
-    rb: rbend, l=1.5, angle=2, tilt=-2, k0=3, k1=1, k2=2, k1s=3, e1=2, e2=1, fint=3, fintx=2, hgap=1, h1=3, h2=2;
+    sb: sbend, l=2, angle=2, tilt=-2, k0=3, k1=1, k2=2, e1=2, e2=1, fint=3, fintx=2, hgap=1, h1=3, h2=2;
+    rb: rbend, l=1.5, angle=2, tilt=-2, k0=3, k1=1, k2=2, e1=2, e2=1, fint=3, fintx=2, hgap=1, h1=3, h2=2;
     qu: quadrupole, l=2, k1=3, k1s=4, tilt=2;  ! ignore thick and ktap
     se: sextupole, L=1, K2=2, K2S=3, TILT=2;  ! ignore ktap
     oc: octupole, L=2, K3=3, K3S=2, TILT=2;
@@ -167,7 +167,7 @@ def example_sequence(temp_context_default_mod):
     rf: rfcavity, L=2, VOLT=1, LAG=2, FREQ=3, HARMON=2, NO_CAVITY_TOTALPATH;  ! ignore N_BESSEL
     mu: multipole, LRAD=1, TILT=2, KNL={3, 4, 5, 6}, KSL={1, 2, 3, 4};
     so: solenoid, l=2, ks=3;  ! ignore ksi
-    
+
     rb_stage1: rbend, l=1;
     rb_stage2: rb_stage1, angle=2;
 
@@ -312,7 +312,7 @@ def test_placeholder(example_sequence):
 
 def test_sbend(example_sequence):
     env, positions, _ = example_sequence
-    # sb: sbend, l=2, angle=2, tilt=-2, k0=3, k1=1, k2=2, k1s=3, e1=2, e2=1,
+    # sb: sbend, l=2, angle=2, tilt=-2, k0=3, k1=1, k2=2, e1=2, e2=1,
     #   fint=3, fintx=2, hgap=1;  ! thick, ktap, h1, h2 we ignore
     sb1 = env['sb1/line']
     xo.assert_allclose(positions['sb1/line'], 15, atol=1e-14)
@@ -321,11 +321,12 @@ def test_sbend(example_sequence):
     assert sb1.k0 == 3
     assert sb1.h == 2 / 2  # angle / l
     assert sb1.k1 == 1
+    assert sb1.k2 == 2.
     assert sb1.knl[0] == 0
     assert sb1.knl[1] == 0
-    assert sb1.knl[2] == 2 * 2  # k2 * l
+    assert sb1.knl[2] == 0
     assert sb1.ksl[0] == 0
-    assert sb1.ksl[1] == 3 * 2  # k1s * l
+    assert sb1.ksl[1] == 0
     assert sb1.edge_entry_angle == 2
     assert sb1.edge_exit_angle == 1
     assert sb1.edge_entry_fint == 3
@@ -336,7 +337,7 @@ def test_sbend(example_sequence):
 
 def test_rbend(example_sequence):
     env, positions, _ = example_sequence
-    # rb: rbend, l=2, angle=1.5, tilt=-2, k0=3, k1=1, k2=2, k1s=3, e1=2, e2=1,
+    # rb: rbend, l=2, angle=1.5, tilt=-2, k0=3, k1=1, k2=2 e1=2, e2=1,
     #   fint=3, fintx=2, hgap=1, h1=3, h2=2;  ! ditto
     rb1 = env['rb1/line']
     xo.assert_allclose(positions['rb1/line'], 17, atol=1e-14)
@@ -352,11 +353,12 @@ def test_rbend(example_sequence):
     assert rb1.k0 == 3
     assert rb1.h == h
     assert rb1.k1 == 1
+    assert rb1.k2 == 2.
     assert rb1.knl[0] == 0
     assert rb1.knl[1] == 0
-    assert rb1.knl[2] == 2 * l  # k2 * l
+    assert rb1.knl[2] == 0
     assert rb1.ksl[0] == 0
-    assert rb1.ksl[1] == 3 * l  # k1s * l
+    assert rb1.ksl[1] == 0
     assert rb1.edge_entry_angle == 2
     assert rb1.edge_exit_angle == 1
     assert rb1.edge_entry_fint == 3
@@ -564,11 +566,12 @@ def test_reversed_sbend(example_sequence):
     assert sb1.k0 == 3
     assert sb1.h == 2 / 2  # angle / l
     assert sb1.k1 == -1
+    assert sb1.k2 == 2.
     assert sb1.knl[0] == 0
     assert sb1.knl[1] == 0
-    assert sb1.knl[2] == 2 * 2  # k2 * l
+    assert sb1.knl[2] == 0
     assert sb1.ksl[0] == 0
-    assert sb1.ksl[1] == 3 * 2  # k1s * l
+    assert sb1.ksl[1] == 0
     assert sb1.edge_entry_angle == 1
     assert sb1.edge_exit_angle == 2
     assert sb1.edge_entry_fint == 2
@@ -578,7 +581,7 @@ def test_reversed_sbend(example_sequence):
 
 
 def test_reversed_rbend(example_sequence):
-    env, _, positions_reversed = example_sequence    # rb: rbend, l=2, angle=1.5, tilt=-2, k0=3, k1=1, k2=2, k1s=3, e1=2, e2=1,
+    env, _, positions_reversed = example_sequence    # rb: rbend, l=2, angle=1.5, tilt=-2, k0=3, k1=1, k2=2, e1=2, e2=1,
     #   fint=3, fintx=2, hgap=1, h1=3, h2=2;  ! ditto
     rb1 = env['rb1/line_reversed']
     xo.assert_allclose(positions_reversed['rb1/line_reversed'], 36 - 17, atol=1e-14)
@@ -594,11 +597,12 @@ def test_reversed_rbend(example_sequence):
     assert rb1.k0 == 3
     assert rb1.h == h
     assert rb1.k1 == -1
+    assert rb1.k2 == 2.
     assert rb1.knl[0] == 0
     assert rb1.knl[1] == 0
-    assert rb1.knl[2] == 2 * l  # k2 * l
+    assert rb1.knl[2] == 0
     assert rb1.ksl[0] == 0
-    assert rb1.ksl[1] == 3 * l  # k1s * l
+    assert rb1.ksl[1] == 0
     assert rb1.edge_entry_angle == 1
     assert rb1.edge_exit_angle == 2
     assert rb1.edge_entry_fint == 2
@@ -779,6 +783,10 @@ def test_load_b2_with_bv_minus_one(tmp_path):
         is_rbend = isinstance(e4, xt.RBend)
 
         for kk in d2.keys():
+
+            if kk == 'prototype':
+                continue  # is always None from cpymad
+
             if kk in ('__class__', 'model', 'side'):
                 assert d2[kk] == d4[kk]
                 continue
@@ -907,7 +915,7 @@ def test_import_seq_length():
     env = xt.load(string=sequence, format='madx')
 
     tt = env.line.get_table()
-    assert np.all(tt.name == np.array(['drift_1', 'qu1', 'drift_2', '_end_point']))
+    assert np.all(tt.name == np.array(['||drift_1', 'qu1', '||drift_2', '_end_point']))
     xo.assert_allclose(tt['s'], np.array([ 0., 18., 20., 30.]), rtol=0, atol=1e-15)
     assert env.line.builder.length == 30
 
@@ -933,32 +941,18 @@ def test_repeated_element_mad_behaviour():
     assert env.seq2['ee'] == element
 
 
-@pytest.mark.parametrize('aper_config', ['attached_to_marker', 'standalone'])
-def test_apertures_on_markers(aper_config):
-    if aper_config == 'attached_to_marker':
-        sequence = """
-            ! Attached to a marker
-            m_circle: marker, apertype="circle", aperture={.2};
-            m_ellipse: marker, apertype="ellipse", aperture={.2, .1};
-            m_rectangle: marker, apertype="rectangle", aperture={.07, .05};
-            m_rectellipse: marker, apertype="rectellipse", aperture={.2, .4, .25, .45};
-            m_racetrack: marker, apertype="racetrack", aperture={.6,.4,.2,.1};
-            m_octagon: marker, apertype="octagon", aperture={.4, .5, 0.5, 1.};
-            m_polygon: marker, apertype="circle", aper_vx={+5.800e-2,+5.800e-2,-8.800e-2}, aper_vy={+3.500e-2,-3.500e-2,+0.000e+0};
-            """
-    else:
-        sequence = """
-            ! Standalone
-            m_circle: circle, aperture={.2};
-            m_ellipse: ellipse, aperture={.2, .1};
-            m_rectangle: rectangle, aperture={.07, .05};
-            m_rectellipse: rectellipse, aperture={.2, .4, .25, .45};
-            m_racetrack: racetrack, aperture={.6,.4,.2,.1};
-            m_octagon: octagon, aperture={.4, .5, 0.5, 1.};
-            m_polygon: circle, aper_vx={+5.800e-2,+5.800e-2,-8.800e-2}, aper_vy={+3.500e-2,-3.500e-2,+0.000e+0};
-            """
+def test_apertures_on_markers():
+
+    sequence = """
+        ! Attached to a marker
+        m_circle: marker, apertype="circle", aperture={.2};
+        m_ellipse: marker, apertype="ellipse", aperture={.2, .1};
+        m_rectangle: marker, apertype="rectangle", aperture={.07, .05};
+        m_rectellipse: marker, apertype="rectellipse", aperture={.2, .4, .25, .45};
+        m_racetrack: marker, apertype="racetrack", aperture={.6,.4,.2,.1};
+        m_octagon: marker, apertype="octagon", aperture={.4, .5, 0.5, 1.};
+        m_polygon: marker, apertype="circle", aper_vx={+5.800e-2,+5.800e-2,-8.800e-2}, aper_vy={+3.500e-2,-3.500e-2,+0.000e+0};
 
-    sequence += """
         line: sequence, l=1;
             m_circle, at=0;
             m_ellipse, at=0.01;
@@ -1052,14 +1046,17 @@ def test_aperture_setting():
     sequence = """
     m_ellipse: marker, apertype="ellipse", aperture={.2, .1};
     m_aper: marker, apertype="rectangle", aperture={.3, .4};
+    m_inferred: marker, aperture=.5;  ! no apertype, should infer circle
 
     line: sequence, l=1;
         m_ellipse, at=0;
         m_aper, at=0.1;
+        m_inferred, at=0.2;
     endsequence;
 
     m_ellipse, aperture={.3, .2};  ! no apertype
     m_aper, apertype="ellipse", aperture={.5, .6};  ! change apertype
+    m_inferred, aperture={.8};
     """
 
     env = xt.load(string=sequence, format='madx')
@@ -1071,6 +1068,8 @@ def test_aperture_setting():
     assert line['m_aper_aper'].a == .5
     assert line['m_aper_aper'].b == .6
 
+    assert line['m_inferred_aper'].a == .8
+
 
 def test_import_thick_with_apertures_and_slice():
     sequence = """
@@ -1139,4 +1138,76 @@ def test_import_thick_with_apertures_and_slice():
         _assert_eq(line[f'elm_aper..{i}'].resolve(line).b_squ, 0.22 ** 2)
 
     for i in range(2):
-        _assert_eq(line[f'elm..{i}']._parent.rot_s_rad, 0.2)
\ No newline at end of file
+        _assert_eq(line[f'elm..{i}']._parent.rot_s_rad, 0.2)
+
+def test_solenoid_zero_length():
+
+    mad_str = """
+        sol1: solenoid, l=1.0, ks=0.5;
+        sol2: sol1, lrad=0.2;
+        sol3: sol2;
+
+        sol4: solenoid, l=0, ks=1.0;
+        sol5: sol4, lrad=0.1;
+        sol6: sol5;
+    """
+
+    env = xt.load(string=mad_str, format='madx')
+
+    assert isinstance(env['sol1'], xt.UniformSolenoid)
+    assert isinstance(env['sol2'], xt.UniformSolenoid)
+    assert isinstance(env['sol3'], xt.UniformSolenoid)
+    assert isinstance(env['sol4'], xt.UniformSolenoid)
+    assert isinstance(env['sol5'], xt.UniformSolenoid)
+    assert isinstance(env['sol6'], xt.UniformSolenoid)
+
+    xo.assert_allclose(env['sol1'].length, 1.0, rtol=0, atol=1e-12)
+    xo.assert_allclose(env['sol2'].length, 1.0, rtol=0, atol=1e-12)
+    xo.assert_allclose(env['sol3'].length, 1.0, rtol=0, atol=1e-12)
+    xo.assert_allclose(env['sol4'].length, 0.0, rtol=0, atol=1e-12)
+    xo.assert_allclose(env['sol5'].length, 0.0, rtol=0, atol=1e-12)
+    xo.assert_allclose(env['sol6'].length, 0.0, rtol=0, atol=1e-12)
+
+def test_bend_k0_neq_h():
+
+    mad_src = """
+        a = 0.1;
+        b1: sbend, l=2.0, angle:=a, k0:=0.2*a, e1=0.02, e2=0.03, fint=1.5, hgap=0.04;
+        seq: sequence, l=2.0;
+        b1: b1, at=1;
+        endsequence;
+    """
+
+    mad = Madx()
+    mad.input(mad_src)
+    mad.beam()
+    mad.use('seq')
+
+    lmad = xt.Line.from_madx_sequence(mad.sequence.seq, deferred_expressions=True)
+    env = xt.load(string=mad_src, format='madx')
+    lenv = env['seq']
+
+    xo.assert_allclose(lenv['b1'].length,
+                    lmad['b1'].length, rtol=0, atol=1e-12)
+    xo.assert_allclose(lenv['b1'].angle,
+                    lmad['b1'].angle, rtol=0, atol=1e-12)
+    xo.assert_allclose(lenv['b1'].k0,
+                    lmad['b1'].k0, rtol=0, atol=1e-12)
+    xo.assert_allclose(lenv['b1'].h,
+                    lmad['b1'].h, rtol=0, atol=1e-12)
+    xo.assert_allclose(lenv['b1'].edge_entry_angle,
+                    lmad['b1'].edge_entry_angle, rtol=0, atol=1e-12)
+    xo.assert_allclose(lenv['b1'].edge_exit_angle,
+                    lmad['b1'].edge_exit_angle, rtol=0, atol=1e-12)
+    xo.assert_allclose(lenv['b1'].edge_entry_fint,
+                    lmad['b1'].edge_entry_fint, rtol=0, atol=1e-12)
+    xo.assert_allclose(lenv['b1'].edge_exit_fint,
+                        lmad['b1'].edge_exit_fint, rtol=0, atol=1e-12)
+    xo.assert_allclose(lenv['b1'].edge_entry_hgap,
+                        lmad['b1'].edge_entry_hgap, rtol=0, atol=1e-12)
+    xo.assert_allclose(lenv['b1'].edge_exit_hgap,
+                        lmad['b1'].edge_exit_hgap, rtol=0, atol=1e-12)
+    xo.assert_allclose(lenv['b1'].edge_entry_angle_fdown,
+                    lmad['b1'].edge_entry_angle_fdown, rtol=0, atol=1e-12)
+    xo.assert_allclose(lenv['b1'].edge_exit_angle_fdown,
+                    lmad['b1'].edge_exit_angle_fdown, rtol=0, atol=1e-12)
\ No newline at end of file
