@@ -14,20 +14,12 @@ def test_ps_multiturn_twiss(test_context):
     test_data_folder = pathlib.Path(
             __file__).parent.joinpath('../test_data').absolute()
 
-    mad = Madx(stdout=False)
-    mad.input("""
-    beam, particle=proton, pc = 14.0;
-    BRHO      = BEAM->PC * 3.3356;
-    """)
-    mad.call(str(test_data_folder / "ps_sftpro/ps.seq"))
-    mad.call(str(test_data_folder / "ps_sftpro/ps_hs_sftpro.str"))
-    mad.use('ps')
 
-    line = xt.Line.from_madx_sequence(mad.sequence.ps, allow_thick=True,
-                                    deferred_expressions=True,
-                                    )
-    line.particle_ref = xt.Particles(mass0=xt.PROTON_MASS_EV,
-                                        q0=1, gamma0=mad.sequence.ps.beam.gamma)
+    env = xt.load([test_data_folder / 'ps_sftpro/ps.seq',
+                   test_data_folder / 'ps_sftpro/ps_hs_sftpro.str'])
+    line = env['ps']
+    line.set_particle_ref('proton', p0c=14e9)
+
     line.twiss_default['method'] = '4d'
     line.build_tracker(test_context)
 
