@@ -273,17 +273,16 @@ def test_orbit_correction_thread(test_context):
 @for_all_test_contexts
 def test_correct_trajectory_transfer_line(test_context):
 
-    mad_ti2 = Madx()
-    mad_ti2.call(str(test_data_folder / 'sps_to_lhc_ti2/ti2.seq'))
-    mad_ti2.call(str(test_data_folder / 'sps_to_lhc_ti2/ti2_liu.str'))
-    mad_ti2.beam()
-    mad_ti2.use('ti2')
-
-    line = xt.Line.from_madx_sequence(mad_ti2.sequence['ti2'])
-    line.particle_ref = xt.Particles(p0c=450e9, mass0=xt.PROTON_MASS_EV, q0=1)
+    env = xt.load([test_data_folder / 'sps_to_lhc_ti2/ti2.seq',
+                   test_data_folder / 'sps_to_lhc_ti2/ti2_liu.str'])
+    line = env['ti2']
+    line.set_particle_ref('proton', p0c=450e9)
     line.build_tracker(_context=test_context)
     tt = line.get_table()
 
+    line.insert('start_ti2', xt.Marker(), at=0.)
+    line.append('end_ti2', xt.Marker())
+
     # Define elements to be used as monitors for orbit correction
     # (in this case all element names starting by "bpm" and not ending by "_entry" or "_exit")
     tt_monitors = tt.rows['bpm.*'].rows['.*(?<!_entry)$'].rows['.*(?<!_exit)$']
@@ -303,7 +302,7 @@ def test_correct_trajectory_transfer_line(test_context):
                         dx=-0.59866300, dpx=0.01603536)
 
     # Reference twiss (no misalignments)
-    tw_ref = line.twiss4d(start='ti2$start', end='ti2$end', init=init)
+    tw_ref = line.twiss4d(start=xt.START, end=xt.END, init=init)
 
     # Introduce misalignments on all quadrupoles
     tt = line.get_table()
@@ -316,13 +315,14 @@ def test_correct_trajectory_transfer_line(test_context):
         line[nn_quad].shift_y = sy
 
     # Twiss before correction
-    tw_before = line.twiss4d(start='ti2$start', end='ti2$end', init=init)
+    tw_before = line.twiss4d(start=xt.START, end=xt.END, init=init)
 
     # Correct trajectory
-    correction = line.correct_trajectory(twiss_table=tw_ref, start='ti2$start', end='ti2$end')
+    correction = line.correct_trajectory(twiss_table=tw_ref,
+                                         start='start_ti2', end='end_ti2')
 
     # Twiss after correction
-    tw_after = line.twiss4d(start='ti2$start', end='ti2$end', init=init)
+    tw_after = line.twiss4d(start=xt.START, end=xt.END, init=init)
 
     # Extract correction strength
     kicks_x = correction.x_correction.get_kick_values()
