@@ -81,156 +81,53 @@ def _handle_per_particle_blocks(sources, local_particle_src):
 
     return out
 
+
 def _generate_track_local_particle_with_transformations(
     element_name,
     allow_rot_and_shift,
     rot_and_shift_from_parent,
-    local_particle_function_name,
     isthick,
-    xofields
+    xofields,
+    is_thin_slice,
 ):
-    source = (
-        '#include <headers/track.h>\n'
-        '#include <headers/particle_states.h>\n'
-        '#include <beam_elements/elements_src/track_misalignments.h>\n'
-        f'GPUFUN void {local_particle_function_name}_with_transformations({element_name}Data el, LocalParticle* part0)'
-        '{\n'
-    )
-
-    if rot_and_shift_from_parent:
-        add_to_call = '__parent'
-    else:
-        add_to_call = ''
+    options = {
+        'ELEMENT_NAME': element_name,
+    }
 
     if allow_rot_and_shift:
-        if ('angle' in xofields or
-           (('ThickSlice' in element_name) and ('Bend' in element_name)) or
-           (('ThinSlice' in element_name) and ('Bend' in element_name))
-        ):
-            element_shape = 'curved'
-            misalign_arguments = 'shift_x, shift_y, shift_s, rot_y_rad, rot_x_rad, rot_s_rad_no_frame, anchor, length, angle, rot_s_rad'
-            get_angle = f'double const angle = {element_name}Data_get{add_to_call}_angle(el)'
-        else:
-            element_shape = 'straight'
-            misalign_arguments = 'shift_x, shift_y, shift_s, rot_y_rad, rot_x_rad, rot_s_rad_no_frame, anchor, length, rot_s_rad'
-            get_angle = ''
-            get_rot_s_rad = ''
-        get_rot_s_rad = 'double const rot_s_rad = atan2(_sin_rot_s, _cos_rot_s)'
+        options['ALLOW_ROT_AND_SHIFT'] = 1
 
-        if 'isthick' in xofields:
-            get_length = (
-                f'double const length = {element_name}Data_get{add_to_call}_isthick(el)'
-                f' ? {element_name}Data_get{add_to_call}_length(el)'
-                f' : 0.0'
-            )
-        elif 'length' in xofields and isthick:
-            get_length = f'double const length = {element_name}Data_get{add_to_call}_length(el)'
-        else:
-            get_length = 'double const length = 0.'
-
-        source += (
-            '    // Transform to local frame\n'
-            f'double const _sin_rot_s = {element_name}Data_get{add_to_call}__sin_rot_s(el);\n'
-            'if (_sin_rot_s > -2.) {\n'
-            f'    double const _cos_rot_s = {element_name}Data_get{add_to_call}__cos_rot_s(el);\n'
-            f'    {get_rot_s_rad};\n'
-            f'    double const shift_x = {element_name}Data_get{add_to_call}__shift_x(el);\n'
-            f'    double const shift_y = {element_name}Data_get{add_to_call}__shift_y(el);\n'
-            f'    double const shift_s = {element_name}Data_get{add_to_call}__shift_s(el);\n'
-            f'    double const rot_x_rad = {element_name}Data_get{add_to_call}__rot_x_rad(el);\n'
-            f'    double const rot_y_rad = {element_name}Data_get{add_to_call}__rot_y_rad(el);\n'
-            f'    double const rot_s_rad_no_frame = {element_name}Data_get{add_to_call}__rot_s_rad_no_frame(el);\n'
-            f'    {get_length};\n'
-            f'    {get_angle};\n'
-            f'    double const anchor = {element_name}Data_get{add_to_call}_rot_shift_anchor(el);\n'
-            f'    int8_t const backtrack = LocalParticle_check_track_flag(part0, XS_FLAG_BACKTRACK);\n'
-            '\n')
-
-        if rot_and_shift_from_parent:
-            source += (
-                "if (rot_x_rad != 0 || rot_y_rad != 0) {\n"
-                " //start_per_particle_block (part0->part)\n"
-                "    LocalParticle_set_state(part, XT_INVALID_SLICE_TRANSFORM);\n"
-                " //end_per_particle_block\n"
-                "}\n"
-            )
-            if element_shape == 'curved':
-                source += (
-                    "if (angle != 0 && (shift_x != 0 || shift_y != 0 || shift_s != 0"
-                    "                   || rot_x_rad !=0 || rot_y_rad != 0 || rot_s_rad_no_frame != 0)) {\n"
-                    " //start_per_particle_block (part0->part)\n"
-                    "    LocalParticle_set_state(part, XT_INVALID_CURVED_SLICE_TRANSFORM);\n"
-                    " //end_per_particle_block\n"
-                "}\n"
-            )
-
-        source += (
-            '     if (!backtrack) {\n'
-            f'      track_misalignment_entry_{element_shape}(part0, {misalign_arguments}, backtrack);'
-            '     } else {\n'
-            f'      track_misalignment_exit_{element_shape}(part0, {misalign_arguments}, backtrack);\n'
-            '     }\n'
-            '\n'
-            '    /* Spin tracking is disabled by the synrad compile flag */\n'
-            '    #ifndef XTRACK_MULTIPOLE_NO_SYNRAD\n'
-            '       // Rotate spin\n'
-            '       //start_per_particle_block (part0->part)\n'
-            '           double const spin_x_0 = LocalParticle_get_spin_x(part);\n'
-            '           double const spin_y_0 = LocalParticle_get_spin_y(part);\n'
-            '           if ((spin_x_0 != 0) || (spin_y_0 != 0)){\n'
-            '               double const spin_x_1 = _cos_rot_s*spin_x_0 + _sin_rot_s*spin_y_0;\n'
-            '               double const spin_y_1 = -_sin_rot_s*spin_x_0 + _cos_rot_s*spin_y_0;\n'
-            '               LocalParticle_set_spin_x(part, spin_x_1);\n'
-            '               LocalParticle_set_spin_y(part, spin_y_1);\n'
-            '          }\n'
-            '       //end_per_particle_block\n'
-            '    #endif\n'
-            '\n'
-            '}\n'
-            f'    {local_particle_function_name}(el, part0);\n'
-            '    // Transform back to global frame\n'
-            'if (_sin_rot_s > -2.) {\n'
-            f'    double const _cos_rot_s = {element_name}Data_get{add_to_call}__cos_rot_s(el);\n'
-            f'    {get_rot_s_rad};\n'
-            f'    double const shift_x = {element_name}Data_get{add_to_call}__shift_x(el);\n'
-            f'    double const shift_y = {element_name}Data_get{add_to_call}__shift_y(el);\n'
-            f'    double const shift_s = {element_name}Data_get{add_to_call}__shift_s(el);\n'
-            f'    double const rot_x_rad = {element_name}Data_get{add_to_call}__rot_x_rad(el);\n'
-            f'    double const rot_y_rad = {element_name}Data_get{add_to_call}__rot_y_rad(el);\n'
-            f'    double const rot_s_rad_no_frame = {element_name}Data_get{add_to_call}__rot_s_rad_no_frame(el);\n'
-            f'    {get_length};\n'
-            f'    {get_angle};\n'
-            f'    double const anchor = {element_name}Data_get{add_to_call}_rot_shift_anchor(el);\n'
-            f'    int8_t const backtrack = LocalParticle_check_track_flag(part0, XS_FLAG_BACKTRACK);\n'
-            '\n'
-            '    /* Spin tracking is disabled by the synrad compile flag */\n'
-            '    #ifndef XTRACK_MULTIPOLE_NO_SYNRAD\n'
-            '       // Rotate spin\n'
-            '       //start_per_particle_block (part0->part)\n'
-            '           double const spin_x_0 = LocalParticle_get_spin_x(part);\n'
-            '           double const spin_y_0 = LocalParticle_get_spin_y(part);\n'
-            '           if ((spin_x_0 != 0) || (spin_y_0 != 0)){\n'
-            '               double const spin_x_1 = _cos_rot_s*spin_x_0 - _sin_rot_s*spin_y_0;\n'
-            '               double const spin_y_1 = _sin_rot_s*spin_x_0 + _cos_rot_s*spin_y_0;\n'
-            '               LocalParticle_set_spin_x(part, spin_x_1);\n'
-            '               LocalParticle_set_spin_y(part, spin_y_1);\n'
-            '          }\n'
-            '       //end_per_particle_block\n'
-            '    #endif\n'
-            '\n'
-            '     if (!backtrack) {\n'
-            f'       track_misalignment_exit_{element_shape}(part0, {misalign_arguments}, backtrack);'
-            '     } else {\n'
-            f'       track_misalignment_entry_{element_shape}(part0, {misalign_arguments}, backtrack);\n'
-            '     }\n'
-            '}\n'
-        )
+    if rot_and_shift_from_parent:
+        options['IS_SLICE'] = 1
+        curves_reference_frame = hasattr(xofields['_parent']._reftype, 'h')
     else:
-        source += (
-            f'    {local_particle_function_name}(el, part0);\n'
-        )
-    source += '}\n'
-    return source
+        curves_reference_frame = 'h' in xofields
+
+    if curves_reference_frame:
+        options['CURVED'] = 1
+
+    if 'isthick' in xofields:
+        options['IS_THICK_DYNAMIC'] = 1
+    elif isthick:
+        options['IS_THICK'] = 1
+
+    if is_thin_slice and curves_reference_frame:
+        options['THIN_SLICE_OF_CURVED_ELEMENT'] = 1
+
+    preamble_lines = []
+    epilogue_lines = []
+
+    for flag, value in options.items():
+        preamble_lines.append(f'#define {flag} {value}')
+        epilogue_lines.append(f'#undef {flag}')
+
+    source_lines = [
+        *preamble_lines,
+        '#include "headers/track_local_particle_with_transformations.h"',
+        *epilogue_lines,
+    ]
+    return '\n'.join(source_lines)
+
 
 def _generate_per_particle_kernel_from_local_particle_function(
                                                 element_name, kernel_name,
@@ -319,79 +216,6 @@ def _generate_per_particle_kernel_from_local_particle_function(
 ''')
     return source
 
-def _tranformations_active(self):
-    no_shift = self.shift_x == 0 and self.shift_y == 0 and self.shift_s == 0
-    no_rot = (
-        self.rot_x_rad == 0 and self.rot_y_rad == 0 and self.rot_s_rad == 0 and
-        self.rot_s_rad_no_frame == 0
-    )
-
-    if no_shift and no_rot:
-        return False
-
-    return True
-
-
-def _disable_transformations_if_needed(self):
-    if not _tranformations_active(self):
-        self._sin_rot_s = -999.
-        self._cos_rot_s = -999.
-    elif self._sin_rot_s < -2.:
-        self._sin_rot_s = 0.
-        self._cos_rot_s = 1.
-
-
-def _rot_s_property(self):
-    if self._sin_rot_s < -2.:
-        return 0.
-    return np.arctan2(self._sin_rot_s, self._cos_rot_s)
-
-def _set_rot_s_property_setter(self, value):
-    self._sin_rot_s = np.sin(value)
-    self._cos_rot_s = np.cos(value)
-    _disable_transformations_if_needed(self)
-
-def _shiftx_property(self):
-    return self._shift_x
-
-def _set_shiftx_property_setter(self, value):
-    self._shift_x = value
-    _disable_transformations_if_needed(self)
-
-def _shifty_property(self):
-    return self._shift_y
-
-def _set_shifty_property_setter(self, value):
-    self._shift_y = value
-    _disable_transformations_if_needed(self)
-
-def _shifts_property(self):
-    return self._shift_s
-
-def _set_shifts_property_setter(self, value):
-    self._shift_s = value
-    _disable_transformations_if_needed(self)
-
-def _rot_x_property(self):
-    return self._rot_x_rad
-
-def _set_rot_x_property_setter(self, value):
-    self._rot_x_rad = value
-    _disable_transformations_if_needed(self)
-
-def _rot_y_property(self):
-    return self._rot_y_rad
-
-def _set_rot_y_property_setter(self, value):
-    self._rot_y_rad = value
-    _disable_transformations_if_needed(self)
-
-def _rot_s_no_frame_property(self):
-    return self._rot_s_rad_no_frame
-
-def _set_rot_s_no_frame_property_setter(self, value):
-    self._rot_s_rad_no_frame = value
-    _disable_transformations_if_needed(self)
 
 class MetaBeamElement(xo.MetaHybridClass):
 
@@ -436,15 +260,20 @@ class MetaBeamElement(xo.MetaHybridClass):
 
         allow_rot_and_shift = data.get('allow_rot_and_shift', True)
 
-        if allow_rot_and_shift:
-            xofields['_sin_rot_s'] = xo.Field(xo.Float64, default=-999.)
-            xofields['_cos_rot_s'] = xo.Field(xo.Float64, default=-999.)
-            xofields['_shift_x'] = xo.Field(xo.Float64, 0)
-            xofields['_shift_y'] = xo.Field(xo.Float64, 0)
-            xofields['_shift_s'] = xo.Field(xo.Float64, 0)
-            xofields['_rot_x_rad'] = xo.Field(xo.Float64, 0)
-            xofields['_rot_y_rad'] = xo.Field(xo.Float64, 0)
-            xofields['_rot_s_rad_no_frame'] = xo.Field(xo.Float64, 0)
+        # For now assume that when there is a parent, the element inherits the parent's transformations
+        rot_and_shift_from_parent = False
+        if '_parent' in xofields.keys():
+            assert 'rot_and_shift_from_parent' in data.keys()
+            rot_and_shift_from_parent = data['rot_and_shift_from_parent']
+
+        if allow_rot_and_shift and not rot_and_shift_from_parent:
+            xofields['shift_x'] = xo.Field(xo.Float64, 0)
+            xofields['shift_y'] = xo.Field(xo.Float64, 0)
+            xofields['shift_s'] = xo.Field(xo.Float64, 0)
+            xofields['rot_s_rad'] = xo.Field(xo.Float64)
+            xofields['rot_x_rad'] = xo.Field(xo.Float64, 0)
+            xofields['rot_y_rad'] = xo.Field(xo.Float64, 0)
+            xofields['rot_s_rad_no_frame'] = xo.Field(xo.Float64, 0)
             xofields['rot_shift_anchor'] = xo.Field(xo.Float64, 0)
 
         data = data.copy()
@@ -487,12 +316,6 @@ class MetaBeamElement(xo.MetaHybridClass):
         # Add dependency on Particles class
         depends_on.append(Particles._XoStruct)
 
-        # For now I assume that when there is a parent, the element inherits the parent's transformations
-        rot_and_shift_from_parent = False
-        if '_parent' in xofields.keys():
-            assert 'rot_and_shift_from_parent' in data.keys()
-            rot_and_shift_from_parent = data['rot_and_shift_from_parent']
-
         track_kernel_name = None
         if ('allow_track' not in data.keys() or data['allow_track']):
             extra_c_source.append(
@@ -500,9 +323,10 @@ class MetaBeamElement(xo.MetaHybridClass):
                     element_name=name,
                     allow_rot_and_shift=(allow_rot_and_shift or rot_and_shift_from_parent),
                     rot_and_shift_from_parent=rot_and_shift_from_parent,
-                    local_particle_function_name=name+'_track_local_particle',
                     isthick=data['_isthick'],
                     xofields=xofields,
+                    is_thin_slice=(
+                        '_ThinSliceElementBase' in (base.__name__ for base in bases)),
                 )
             )
 
@@ -573,15 +397,6 @@ class MetaBeamElement(xo.MetaHybridClass):
                 additional_arg_names=tuple(arg.name for arg in desc.args),
             ))
 
-        if allow_rot_and_shift:
-            new_class.rot_s_rad = property(_rot_s_property, _set_rot_s_property_setter)
-            new_class.shift_x = property(_shiftx_property, _set_shiftx_property_setter)
-            new_class.shift_y = property(_shifty_property, _set_shifty_property_setter)
-            new_class.shift_s = property(_shifts_property, _set_shifts_property_setter)
-            new_class.rot_x_rad = property(_rot_x_property, _set_rot_x_property_setter)
-            new_class.rot_y_rad = property(_rot_y_property, _set_rot_y_property_setter)
-            new_class.rot_s_rad_no_frame = property(_rot_s_no_frame_property, _set_rot_s_no_frame_property_setter)
-
         return new_class
 
 
@@ -596,6 +411,7 @@ class BeamElement(xo.HybridClass, metaclass=MetaBeamElement):
     skip_in_loss_location_refinement = False
     needs_rng = False
     name_associated_aperture = None
+    prototype = None
 
     def __init__(self, *args, **kwargs):
         xo.HybridClass.__init__(self, *args, **kwargs)
@@ -713,9 +529,10 @@ class BeamElement(xo.HybridClass, metaclass=MetaBeamElement):
 
     def xoinitialize(self, **kwargs):
         rot_s_rad = kwargs.pop('rot_s_rad', None)
-        shift_x = kwargs.pop('shift_x', None)
-        shift_y = kwargs.pop('shift_y', None)
-        shift_s = kwargs.pop('shift_s', None)
+        # For the shifts we accept both shift_x and _shift_x for backward compatibility
+        shift_x = kwargs.pop('shift_x', kwargs.pop('_shift_x', None))
+        shift_y = kwargs.pop('shift_y', kwargs.pop('_shift_y', None))
+        shift_s = kwargs.pop('shift_s', kwargs.pop('_shift_s', None))
         rot_x_rad = kwargs.pop('rot_x_rad', None)
         rot_y_rad = kwargs.pop('rot_y_rad', None)
         rot_s_rad_no_frame = kwargs.pop('rot_s_rad_no_frame', None)
@@ -725,6 +542,27 @@ class BeamElement(xo.HybridClass, metaclass=MetaBeamElement):
         if rot_s_rad is not None:
             self.rot_s_rad = rot_s_rad
 
+        rot_s_rad_legacy_from_trig = False
+        sin_s_rad = 0
+        cos_s_rad = 1
+
+        if '_sin_rot_s' in kwargs or '_cos_rot_s' in kwargs:
+            rot_s_rad_legacy_from_trig = True
+            sin_s_rad = kwargs.pop('_sin_rot_s')
+            cos_s_rad = kwargs.pop('_cos_rot_s')
+
+        if rot_s_rad_legacy_from_trig:
+            computed_rot_s_rad = np.arctan2(sin_s_rad, cos_s_rad)
+            if rot_s_rad is not None:
+                if not np.isclose(rot_s_rad, computed_rot_s_rad, atol=1e-14, rtol=1e-14):
+                    raise ValueError(
+                        f'{type(self).__name__} initialised with both `rot_s_rad` '
+                        f'and `_sin_rot_s` or `_cos_rot_s` arguments, but they are '
+                        f'inconsistent with each other.'
+                    )
+            else:
+                self.rot_s_rad = computed_rot_s_rad
+
         if shift_x is not None:
             self.shift_x = shift_x
 
@@ -780,6 +618,24 @@ class BeamElement(xo.HybridClass, metaclass=MetaBeamElement):
             out.prototype = self.prototype
         return out
 
+    @property
+    def transformations_active(self):
+        if not self.allow_rot_and_shift:
+            return False
+        if hasattr(self, '_parent') and self.rot_and_shift_from_parent:
+            return self._parent.transformations_active()
+        if np.any([
+            self.shift_x,
+            self.shift_y,
+            self.shift_s,
+            self.rot_s_rad,
+            self.rot_x_rad,
+            self.rot_y_rad,
+            self.rot_s_rad_no_frame,
+        ]):
+            return True
+        return False
+
     @property
     def _add_to_repr(self):
         out = []
