@@ -21,19 +21,20 @@ void Misalignment_track_local_particle(MisalignmentData el, LocalParticle* part0
     const double anchor = MisalignmentData_get_anchor(el);
     const double length = MisalignmentData_get_length(el);
     const double angle = MisalignmentData_get_angle(el);
+    const double h = MisalignmentData_get_h(el);
     const double tilt = MisalignmentData_get_tilt(el);
     const double is_exit = MisalignmentData_get_is_exit(el);
     const int8_t backtrack = 0;
 
     if (!is_exit) {
         if (NONZERO(angle)) {
-            track_misalignment_entry_curved(part0, dx, dy, ds, theta, phi, psi, anchor, length, angle, tilt, backtrack);
+            track_misalignment_entry_curved(part0, dx, dy, ds, theta, phi, psi, anchor, length, angle, h, tilt, backtrack);
         } else {
             track_misalignment_entry_straight(part0, dx, dy, ds, theta, phi, psi, anchor, length, tilt, backtrack);
         }
     } else {
         if (NONZERO(angle)) {
-            track_misalignment_exit_curved(part0, dx, dy, ds, theta, phi, psi, anchor, length, angle, tilt, backtrack);
+            track_misalignment_exit_curved(part0, dx, dy, ds, theta, phi, psi, anchor, length, angle, h, tilt, backtrack);
         } else {
             track_misalignment_exit_straight(part0, dx, dy, ds, theta, phi, psi, anchor, length, tilt, backtrack);
         }
