@@ -26,6 +26,19 @@ void YRotation_single_particle(LocalParticle* part, double sin_angle, double cos
     double y_hat = y - tan_angle*x*py/(pz*ptt);
     double t_hat = t + tan_angle*x*(1.0/beta0+pt)/(pz*ptt);
 
+    /* Spin tracking is disabled by the synrad compile flag */
+    #ifndef XTRACK_MULTIPOLE_NO_SYNRAD
+        /* Rotate spin */
+        double const spin_x_0 = LocalParticle_get_spin_x(part);
+        double const spin_z_0 = LocalParticle_get_spin_z(part);
+        if ((spin_x_0 != 0) || (spin_z_0 != 0)){
+            double const spin_x_1 = cos_angle*spin_x_0 - sin_angle*spin_z_0;
+            double const spin_z_1 = sin_angle*spin_x_0 + cos_angle*spin_z_0;
+            LocalParticle_set_spin_x(part, spin_x_1);
+            LocalParticle_set_spin_z(part, spin_z_1);
+        }
+    #endif
+
     LocalParticle_set_x(part, x_hat);
     LocalParticle_set_px(part, px_hat);
     LocalParticle_set_y(part, y_hat);
