@@ -1,8 +1,11 @@
 import numpy as np
 import xtrack as xt
-import xdeps as xd
 from enum import Enum
 
+from xdeps.refs import is_ref
+from xtrack.functions import Functions
+
+
 LUA_VARS_PER_CHUNK = 200
 
 class MadType(Enum):
@@ -13,7 +16,7 @@ def expr_to_mad_str(expr):
 
     expr_str = str(expr)
 
-    fff = xt.line.Functions()
+    fff = Functions()
     for nn in fff._mathfunctions:
         expr_str = expr_str.replace(f'f.{nn}(', f'{nn}(')
         expr_str = expr_str.replace(f'f[\'{nn}\'](', f'{nn}(')
@@ -49,7 +52,7 @@ def _replace_var_dots_with_underscores(expr, substituted_vars):
     return expr
 
 def mad_str_or_value(var):
-    if _is_ref(var):
+    if is_ref(var):
         out = expr_to_mad_str(var)
         out = out.strip('._expr')
         return out
@@ -59,7 +62,7 @@ def mad_str_or_value(var):
 def mad_assignment(lhs, rhs, mad_type=MadType.MADX, substituted_vars=None):
     if mad_type == MadType.MADNG:
         lhs = lhs.replace('.', '_')  # replace '.' with '_' for MADNG compatibility
-    if _is_ref(rhs):
+    if is_ref(rhs):
         rhs = mad_str_or_value(rhs)
         rhs = _replace_var_dots_with_underscores(rhs, substituted_vars) if mad_type == MadType.MADNG else rhs
     if isinstance(rhs, str):
@@ -90,7 +93,6 @@ def _handle_tokens_madng(tokens, substituted_vars):
     return tokens
 
 _ge = xt.elements._get_expr
-_is_ref = xd.refs.is_ref
 
 def _knl_ksl_to_mad(mult):
     weight = 1
@@ -113,14 +115,21 @@ def _knl_ksl_to_mad(mult):
 def _get_eref(line, name):
     return line.ref.elements[name]
 
-def _handle_transforms(tokens, el, mad_type=MadType.MADX, substituted_vars=None):
-    if el.shift_x._expr is not None or el.shift_x._value:
-        tokens.append(mad_assignment('dx', _ge(el.shift_x), mad_type, substituted_vars=substituted_vars))
-    if el.shift_y._expr is not None or el.shift_y._value:
-        tokens.append(mad_assignment('dy', _ge(el.shift_y), mad_type, substituted_vars=substituted_vars))
-    if el.rot_s_rad._expr is not None or el.rot_s_rad._value:
-        tokens.append(mad_assignment('tilt', _ge(el.rot_s_rad), mad_type, substituted_vars=substituted_vars))
-    if el.shift_s._expr is not None or el.shift_s._value:
+def _handle_transforms(tokens, el_ref, mad_type=MadType.MADX, substituted_vars=None):
+    def _defined_and_nonzero(field_name):
+        el_instance = el_ref._value
+        if not hasattr(el_instance, field_name):
+            return False
+        field = getattr(el_ref, field_name)
+        return field._expr is not None or field._value != 0
+
+    if _defined_and_nonzero('shift_x'):
+        tokens.append(mad_assignment('dx', _ge(el_ref.shift_x), mad_type, substituted_vars=substituted_vars))
+    if _defined_and_nonzero('shift_y'):
+        tokens.append(mad_assignment('dy', _ge(el_ref.shift_y), mad_type, substituted_vars=substituted_vars))
+    if _defined_and_nonzero('rot_s_rad'):
+        tokens.append(mad_assignment('tilt', _ge(el_ref.rot_s_rad), mad_type, substituted_vars=substituted_vars))
+    if _defined_and_nonzero('shift_s'):
         raise NotImplementedError("shift_s is not yet supported in mad writer")
 
 def cavity_to_mad_str(eref, mad_type=MadType.MADX, substituted_vars=None):
@@ -394,6 +403,7 @@ def bend_to_mad_str(eref, bend_type='sbend', mad_type=MadType.MADX, substituted_
         tokens.append(mad_assignment('kill_ent_fringe', edge_entry_active_val, mad_type, substituted_vars=substituted_vars))
         tokens.append(mad_assignment('kill_exi_fringe', edge_exit_active_val, mad_type, substituted_vars=substituted_vars))
     tokens.append(mad_assignment('k1', _ge(eref.k1), mad_type, substituted_vars=substituted_vars))
+    tokens.append(mad_assignment('k2', _ge(eref.k2), mad_type, substituted_vars=substituted_vars))
     knl_token, ksl_token = _knl_ksl_to_mad(eref)
     tokens.append(knl_token)
     tokens.append(ksl_token)
@@ -538,7 +548,15 @@ xsuite_to_mad_converters = {
     xt.SRotation: srotation_to_mad_str,
     xt.RFMultipole: rfmultipole_to_mad_str,
     xt.CrabCavity: crabcavity_to_mad_str,
-    xt.DriftSlice: drift_slice_to_mad_str
+    xt.DriftSlice: drift_slice_to_mad_str,
+}
+
+element_types_converted_to_markers = {
+    xt.LimitEllipse,
+    xt.LimitPolygon,
+    xt.LimitRacetrack,
+    xt.LimitRect,
+    xt.LimitRectEllipse,
 }
 
 def element_to_mad_str(
@@ -553,9 +571,15 @@ def element_to_mad_str(
 
     el = line._element_dict[name]
     eref = _get_eref(line, name)
+
+    while isinstance(el, xt.Replica):
+        eref = line.ref[el.parent_name]
+        el = line._element_dict[el.parent_name]
+
     parent_flag = hasattr(el, '_parent')
 
-    if el.__class__ == xt.Marker or parent_flag and el._parent.__class__ == xt.Marker:
+    if (el.__class__ == xt.Marker or el.__class__ in element_types_converted_to_markers
+        or parent_flag and el._parent.__class__ == xt.Marker):
         return marker_to_mad_str(name, line, mad_type=mad_type, substituted_vars=substituted_vars)
 
     if el.__class__ not in xsuite_to_mad_converters:
@@ -605,7 +629,9 @@ def to_madx_sequence(line, name='seq', mode='sequence'):
         tt_name = tt.name
         tt_s = tt.s
         tt_isthick = tt.isthick
-        for ii in range(len(tt.name)):
+        for ii, nn in enumerate(tt.name):
+            if nn.startswith("||drift_"):
+                continue
             nn = tt_name[ii]
             if not(tt_isthick[ii]):
                 s_dict[nn] = tt_s[ii]
@@ -613,7 +639,8 @@ def to_madx_sequence(line, name='seq', mode='sequence'):
                 s_dict[nn] = 0.5 * (tt_s[ii] + tt_s[ii+1])
 
         for nn in line.element_names:
-
+            if nn.startswith("||drift_"):
+                continue
             el = line._element_dict[nn]
             el_str = element_to_mad_str(nn, line, mad_type=MadType.MADX)
             if nn + '_tilt_entry' in line._element_dict:
@@ -633,7 +660,7 @@ def to_madx_sequence(line, name='seq', mode='sequence'):
     mad_input = vars_str + '\n' + machine_str + '\n'
     return mad_input
 
-def to_madng_sequence(line, name='seq', mode='sequence'):
+def to_madng_sequence(line, name='seq'):
     code_str = ""
     chunk_start = "(function()\t -- Begin chunk\n"
     chunk_end = "end)();\t -- End chunk\n"
@@ -667,7 +694,7 @@ def to_madng_sequence(line, name='seq', mode='sequence'):
     s_dict = {}
     el_strs = []
 
-    for ii, nn in enumerate(tt.name[:-1]): # ignore "_end_point"
+    for ii, nn in enumerate(tt.env_name[:-1]): # ignore "_end_point"
         if not(tt.isthick[ii]):
             s_dict[nn] = tt.s[ii]
         else:
@@ -681,7 +708,8 @@ def to_madng_sequence(line, name='seq', mode='sequence'):
             continue
 
         # Misalignments
-        if hasattr(el, 'shift_x') and hasattr(el, 'shift_y'):
+        if (hasattr(el, 'shift_x') and hasattr(el, 'shift_y')
+            and el.__class__ not in element_types_converted_to_markers):
             el_str += f", misalign =\\ {{dx={mad_str_or_value(_ge(line.ref[nn].shift_x))}, dy={mad_str_or_value(_ge(line.ref[nn].shift_y))}}}"
         el_strs.append(el_str)
 
